# !/usr/bin/env python
# -*- coding: utf-8 -*-

__name__ = 'korNum'
__description__ = 'change Korean tex number <---> Arabian number'
__version__ = '0.0.0'
__url__ = 'https://github.com/study-ai-data/korNum'
__download_url__ = 'https://github.com/study-ai-data/korNum'
__install_requires__ = [
]
__license__ = 'MIT'

from korNum.chgList import *
from korNum.chgFormat import *
